==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property subjectAlternativeNames
 * @property trusts
 */
public data class GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation(
    public val subjectAlternativeNames:
    List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationSubjectAlternativeName>,
    public val trusts: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation):
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation =
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation(
                subjectAlternativeNames = javaType.subjectAlternativeNames().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationSubjectAlternativeName.Companion.toKotlin(args0)
                    })
                }),
                trusts = javaType.trusts().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property subjectAlternativeNames
 * @property trusts
 */
public data class GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation(
    public val subjectAlternativeNames: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationSubjectAlternativeName>,
    public val trusts: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation): GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation =
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation(
                subjectAlternativeNames = javaType.subjectAlternativeNames().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationSubjectAlternativeName.Companion.toKotlin(args0)
                    })
                }),
                trusts = javaType.trusts().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
